@@ -17,7 +17,7 @@ def tipo_colonna(df, colonna):
 def leggi_csv(file_name):
     import time
     start = time.time()
-    df = pd.read_csv(file_name,encoding='utf-8')
+    df = pd.read_csv(file_name)
     end = time.time()
     print("Tempo impiegato per leggere il file: ", end-start)
     return df
